summaryrefslogtreecommitdiff
path: root/test/unit/context/cdlist_black.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'test/unit/context/cdlist_black.cpp')
-rw-r--r--test/unit/context/cdlist_black.cpp8
1 files changed, 4 insertions, 4 deletions
diff --git a/test/unit/context/cdlist_black.cpp b/test/unit/context/cdlist_black.cpp
index 2339962ac..e903492ee 100644
--- a/test/unit/context/cdlist_black.cpp
+++ b/test/unit/context/cdlist_black.cpp
@@ -9,9 +9,9 @@
** All rights reserved. See the file COPYING in the top-level source
** directory for licensing information.\endverbatim
**
** \brief Black box testing of CVC4::context::CDList<>.
**
** Black box testing of CVC4::context::CDList<>.
**/
#include <limits.h>
@@ -24,7 +24,7 @@
#include "memory.h"
#include "test_context.h"
-namespace CVC4 {
+namespace CVC5 {
using namespace context;
@@ -163,4 +163,4 @@ TEST_F(TestContextBlackCDList, pop_below_level_created)
list.push_back(42);
}
} // namespace test
-} // namespace CVC4
+} // namespace CVC5
generated by cgit on debian on lair
contact matthew@masot.net with questions or feedback
@@ -9,9 +9,9 @@
** directory for licensing information.\endverbatim
**
- ** \brief Black box testing of CVC4::context::CDList<>.
+ ** \brief Black box testing of CVC5::context::CDList<>.
**
@@ -9,9 +9,9 @@
**
- ** Black box testing of CVC4::context::CDList<>.
+ ** Black box testing of CVC5::context::CDList<>.
**/
#include <limits.h>